@@ -35,13 +35,7 @@ import shutil
 import pickle
 import cairo
 
-try:
-	import psyco
-	psyco.full()
-except ImportError:
-	print 'Psyco not installed, the program will just run slower'
-
-print "DeVeDe 3.9"
+print "DeVeDe 3.10"
 if sys.platform!="win32":
 	print "Locale: "+str(os.environ["LANG"])
 
@@ -87,6 +81,10 @@ if tipo==0:
 	sys.path.append("/usr/lib/devede")
 	font_path="/usr/share/devede"
 	pic_path="/usr/share/devede"
+	other_path="/usr/share/devede"
+	help_path="/usr/share/doc/devede"
+	print "Using package-installed files"
+	
 elif tipo==1:
 	# if the files aren't at /usr, try with /usr/local
 	#gettext.bindtextdomain('devede', '/usr/share/locale')
@@ -102,6 +100,10 @@ elif tipo==1:
 	sys.path.append("/usr/local/lib/devede")
 	font_path="/usr/local/share/devede"
 	pic_path="/usr/local/share/devede"
+	other_path="/usr/local/share/devede"
+	help_path="/usr/local/share/doc/devede"
+	print "Using local-installed files"
+	
 elif tipo==2:
 	# if the files aren't at /usr/local, try with ./
 	#gettext.bindtextdomain('devede', './po/')
@@ -117,6 +119,10 @@ elif tipo==2:
 	sys.path.append(os.getcwd())#("./")
 	font_path=os.getcwd()#"./"
 	pic_path=os.path.join(font_path, "pixmaps") #pic_path=font_path
+	other_path=os.path.join(font_path,"pixmaps")
+	help_path=os.path.join(font_path,"doc")
+	print "Using direct files"
+	
 else:
 	print "Can't locate extra files. Aborting."
 	sys.exit(1)
@@ -188,19 +194,16 @@ if pic_path[-1]!=os.sep:
 global_vars["PAL"]=True
 global_vars["disctocreate"]=""
 global_vars["path"]=pic_path
+global_vars["install_path"]=other_path
 global_vars["menu_widescreen"]=False
-global_vars["menu_PAL"]=True
 global_vars["gladefile"]=glade
 global_vars["erase_temporary_files"]=True
 global_vars["number_actions"]=1
-global_vars["menu_bgcolor"]=[0,0,0,49152]
-global_vars["menu_font_color"]=[65535,65535,65535,65535]
-global_vars["menu_selc_color"]=[0,65535,65535,65535]
-global_vars["menu_alignment"]=2 # middle
 global_vars["expand_advanced"]=False
 global_vars["erase_files"]=True
 global_vars["action_todo"]=2
 global_vars["filmpath"]=""
+global_vars["help_path"]=help_path
 
 if font_path[-1]!=os.sep:
 	font_path+=os.sep
