@@ -85,12 +85,11 @@ class disctype:
 		
 		if self.main_window==None:
 			self.main_window=devede_main.main_window(self.global_vars,self.show_again)
-		self.global_vars["action_todo"]=2
-		self.global_vars["erase_files"]=True
 		self.main_window.set_disc_type(True)
 		self.main_window.show()
 		self.window.hide()
 
+
 	def show_again(self):
 		
 		""" Callback which is called from main window when the user wants to change the
