@@ -159,6 +159,41 @@ class load_save_config:
 			w = devede_dialogs.show_error(self.gladefile,_("Can't find the menu background. I'll open the disc structure anyway with the default menu background, so don't forget to fix it before creating the disc."))
 			w = None
 			global_vars2["menu_bg"]=self.global_vars["path"]+"background.png"
+			
+		use_default_sound=False
+		
+		if False==global_vars2.has_key("menu_sound"):
+			use_default_sound=True
+		else:
+			try:
+				os.stat(global_vars2["menu_sound"])
+			except:
+				use_default_sound=True
+				w = devede_dialogs.show_error(self.gladefile,_("Can't find the menu soundtrack file. I'll open the disc structure anyway with a silent soundtrack, so don't forget to fix it before creating the disc."))
+				w = None
+		
+		if False==global_vars2.has_key("menu_halignment"):
+			global_vars2["menu_halignment"]=2 # center
+			
+		if False==global_vars2.has_key("menu_shadow_color"):
+			global_vars2["menu_shadow_color"]=[0,0,0,0]
+			
+		if False==global_vars2.has_key("menu_title_shadow"):
+			global_vars2["menu_title_shadow"]=[0,0,0,0]
+			
+		if use_default_sound:
+			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.mp3")
+
+		test=devede_newfiles.file_get_params()
+		check,channels=test.read_file_values(global_vars2["menu_sound"],True)
+		if (check!=False) or (channels!=1):
+			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.mp3")
+			w = devede_dialogs.show_error(self.gladefile,_("The menu soundtrack seems damaged. Using the default silent soundtrack."))
+			w = None
+			check,channels=test.read_file_values(global_vars2["menu_sound"],True)
+
+		global_vars2["menu_sound_duration"]=test.length
+		test=None
 
 		while (len(self.structure)>0):
 			self.structure.pop()
@@ -174,6 +209,11 @@ class load_save_config:
 			self.global_vars["menu_selc_color"]=[0,65535,65535,65535]
 			self.global_vars["menu_alignment"]=2 # middle
 
+		if self.global_vars.has_key("menu_title_text"):
+			self.global_vars["menu_title_color"]=[0,0,0,65535]
+			self.global_vars["menu_title_text"]=""
+			self.global_vars["menu_title_fontname"]="Sans 14"
+
 		if global_vars2.has_key("erase_files")==False:
 			w=self.tree.get_widget("create_iso")
 			w.set_active(True)
@@ -187,7 +227,7 @@ class load_save_config:
 
 	def save(self,mode):
 	
-		""" This method stores the current disk structure in a file. If MODE is True,
+		""" This method stores the current disc structure in a file. If MODE is True,
 			it will ask before a new name. If it's False and there's a filename
 			(from a previous save), it will overwrite the old file """
 	
@@ -235,13 +275,19 @@ class load_save_config:
 			vars["menu_widescreen"]=self.global_vars["menu_widescreen"]
 			vars["PAL"]=self.global_vars["PAL"]
 			vars["menu_bg"]=self.global_vars["menu_bg"]
-			vars["menu_PAL"]=self.global_vars["menu_PAL"]
+			vars["menu_sound"]=self.global_vars["menu_sound"]
 			vars["menu_bgcolor"]=self.global_vars["menu_bgcolor"]
 			vars["menu_font_color"]=self.global_vars["menu_font_color"]
 			vars["menu_selc_color"]=self.global_vars["menu_selc_color"]
+			vars["menu_shadow_color"]=self.global_vars["menu_shadow_color"]
 			vars["menu_alignment"]=self.global_vars["menu_alignment"]
+			vars["menu_halignment"]=self.global_vars["menu_halignment"]
 			vars["struct_name"]=self.global_vars["struct_name"]
 			vars["fontname"]=self.global_vars["fontname"]
+			vars["menu_title_color"]=self.global_vars["menu_title_color"]
+			vars["menu_title_shadow"]=self.global_vars["menu_title_shadow"]
+			vars["menu_title_text"]=self.global_vars["menu_title_text"]
+			vars["menu_title_fontname"]=self.global_vars["menu_title_fontname"]
 			
 			w=self.tree.get_widget("erase_files")
 			vars["erase_files"]=w.get_active()
