@@ -34,6 +34,7 @@ import devede_loadsave
 import devede_title_properties
 import devede_dialogs
 import devede_convert
+import devede_help
 
 class main_window:
 	
@@ -76,14 +77,13 @@ class main_window:
 		
 		self.callback=callback # callback to call to show again the SELECT_DISK dialog
 		
-		self.window.show()
-		
-		w=self.tree.get_widget("multicore")
-		if (self.global_vars["multicore"]==1):
-			w.set_active(False)
+		if global_vars["PAL"]:
+			w=self.tree.get_widget("default_pal")
 		else:
-			w.set_active(True)
-			self.global_vars["multicore"]=self.get_cores()
+			w=self.tree.get_widget("default_ntsc")
+		w.set_active(True)
+		
+		self.window.show()
 		
 		print "Cores: "+str(self.get_cores())
 
@@ -110,14 +110,37 @@ class main_window:
 
 	def set_default_global(self):
 		
-		self.global_vars["fontname"]="Sans 12"
+		""" Sets the default GLOBAL vars each time the user wants to create a new disc """
+		
+		self.global_vars["action_todo"]=2
+		self.global_vars["erase_files"]=True
 		self.global_vars["struct_name"]=""
 		self.global_vars["do_menu"]=True
-		self.global_vars["menu_bg"]=self.global_vars["path"]+"background.png"
+		self.global_vars["menu_bg"]=os.path.join(self.global_vars["path"],"background.png")
+		self.global_vars["menu_sound"]=os.path.join(self.global_vars["path"],"silence.mp3")
+		test=devede_newfiles.file_get_params()
+		check,channels=test.read_file_values(self.global_vars["menu_sound"],True)
+		if (check!=False) or (channels!=1):
+			self.global_vars["menu_sound_duration"]=20
+		else:
+			self.global_vars["menu_sound_duration"]=test.length
+		print "Longitud sonido: "+str(test.length)
+		test=None
 		self.global_vars["titlecounter"]=2
 		self.current_title_selected=-1
 		self.current_file_selected=-2
-
+		self.global_vars["fontname"]="Sans 12"
+		self.global_vars["menu_bgcolor"]=[0,0,0,49152]
+		self.global_vars["menu_font_color"]=[65535,65535,65535,65535]
+		self.global_vars["menu_selc_color"]=[0,65535,65535,65535]
+		self.global_vars["menu_shadow_color"]=[0,0,0,0]
+		self.global_vars["menu_alignment"]=2 # middle
+		self.global_vars["menu_halignment"]=2 # center
+		self.global_vars["menu_title_color"]=[0,0,0,65535]
+		self.global_vars["menu_title_shadow"]=[0,0,0,0]
+		self.global_vars["menu_title_text"]=""
+		self.global_vars["menu_title_fontname"]="Sans 14"
+		
 
 	def set_disc_type(self,delete_structure):
 		
@@ -126,6 +149,7 @@ class main_window:
 		if delete_structure:
 			self.structure=[]
 			self.structure.append(self.create_new_structure(1))
+		self.set_default_global()
 		
 		self.disctocreate = self.global_vars["disctocreate"]
 		
@@ -144,26 +168,18 @@ class main_window:
 		
 		w1 = self.tree.get_widget("frame1") # contains the titles
 		w2 = self.tree.get_widget("create_dvd") # toggle to create the DVD structure
-		w4 = self.tree.get_widget("domenu") # checkbox to create/not create the menu
 		w5 = self.tree.get_widget("menuoptions") # button to show the menu options
 		w6 = self.tree.get_widget("menu_preview") # button to preview the menu
 		
 		if self.disctocreate == "dvd":
-			if delete_structure:
-				self.global_vars["do_menu"] = True
-			w4.set_active(self.global_vars["do_menu"])
 			w1.show()
 			w2.show()
-			w4.show()
 			w5.show()
 			w6.show()
 		else:
 			self.global_vars["do_menu"] = False
-			w = self.tree.get_widget("domenu")
-			w.set_active(False)
 			w1.hide()
 			w2.hide()
-			w4.hide()
 			w5.hide()
 			w6.hide()
 		
@@ -184,6 +200,7 @@ class main_window:
 				w=self.tree.get_widget("create_dvd")
 			else:
 				w=self.tree.get_widget("only_convert")
+				self.global_vars["action_todo"]=0
 			w.set_active(True)
 		
 		w=self.tree.get_widget("erase_files")
@@ -197,6 +214,13 @@ class main_window:
 		lchapters=self.tree.get_widget("lchapters")
 		lchapters.get_selection().select_path( (0,))
 		
+		w=self.tree.get_widget("multicore")
+		if (self.global_vars["multicore"]==1):
+			w.set_active(False)
+		else:
+			w.set_active(True)
+			self.global_vars["multicore"]=self.get_cores()
+		
 		# refresh the title and chapter lists		
 		self.refresh_titles()
 		self.refresh_chapters()
@@ -217,6 +241,10 @@ class main_window:
 			AUDIORATE is the audio rate """
 		
 		length = float(element["olength"])
+		speed1,speed2=devede_other.get_speedup(element)
+		if (speed1!=speed2): # we are speeding up the film, so we must take it into account
+			length*=((float(speed2))/(float(speed1)))
+
 		if element["cutting"]!=0: # we want only half the file
 			length/=2
 
@@ -306,6 +334,8 @@ class main_window:
 		
 		discsize,minrate,maxrate=devede_other.get_dvd_size(self.tree,self.disctocreate)	
 		discsize*=1000 # size in kbytes
+		# remove the space needed by menus
+		discsize-=devede_other.calcule_menu_size(self.structure,self.global_vars["menu_sound_duration"])
 		
 		size_error=False
 		dowhile=True
@@ -355,7 +385,7 @@ class main_window:
 					break
 
 		if size_error:
-			devede_dialogs.show_error(self.gladefile,_("Too many videos for this disk size.\nPlease, select a bigger disk type or remove some videos."))
+			devede_dialogs.show_error(self.gladefile,_("Too many videos for this disc size.\nPlease, select a bigger disc type or remove some videos."))
 		
 		self.set_video_values()
 
@@ -419,6 +449,15 @@ class main_window:
 			error=None
 	
 	
+	def on_default_pal_toggled(self,widget):
+		
+		if widget.get_active():
+			self.global_vars["PAL"]=True
+		else:
+			self.global_vars["PAL"]=False
+		print "PAL: "+str(self.global_vars["PAL"])
+	
+	
 	def on_chapterclick(self,widget,event):
 	
 		""" Callback for click event in the chapter list. It
@@ -441,8 +480,8 @@ class main_window:
 			for title in self.structure:
 				total+=len(title)-1
 			
-			if total>99:
-				devede_dialogs.show_error(self.gladefile,(_("Your project contains %(X)d movie files, but the maximum is 99. Please, remove some files and try again.")) % {"X":total})
+			if total>90:
+				devede_dialogs.show_error(self.gladefile,(_("Your project contains %(X)d movie files, but the maximum is 90. Please, remove some files and try again.")) % {"X":total})
 				return
 	
 		actions=0	
@@ -639,18 +678,7 @@ class main_window:
 		self.set_buttons()
 
 	
-	# dvd-menu-related callbacks
-	
-	
-	def on_domenu_toggled(self,widget):
-	
-		w1=self.tree.get_widget("domenu")
-		w2=self.tree.get_widget("menuoptions")
-		w3=self.tree.get_widget("menu_preview")
-		w2.set_sensitive(w1.get_active())
-		w3.set_sensitive(w1.get_active())
-		self.global_vars["do_menu"]=w1.get_active()
-	
+	# dvd-menu-related callbacks	
 	
 	def on_menu_preview_clicked(self,widget):
 	
@@ -660,7 +688,7 @@ class main_window:
 	
 	def on_menuoptions_clicked(self,widget):
 	
-		window=devede_dvdmenu.menu_options(self.gladefile,self.global_vars)
+		window=devede_dvdmenu.menu_options(self.gladefile,self.structure,self.global_vars,self.set_video_values)
 		window=None
 	
 
@@ -698,6 +726,11 @@ class main_window:
 		self.refresh_chapters()
 		self.set_buttons()
 		self.set_title()
+		if self.global_vars["PAL"]:
+			w=self.tree.get_widget("default_pal")
+		else:
+			w=self.tree.get_widget("default_ntsc")
+		w.set_active(True)
 		load=None
 
 	
@@ -711,6 +744,16 @@ class main_window:
 		self.save_file(True)
 
 	
+	def on_main_help_clicked(self,widget):
+		
+		help_class=devede_help.show_help(self.gladefile,self.global_vars["help_path"],"main.html")
+	
+	
+	def on_help_index_activate(self,widget):
+	
+		help_class=devede_help.show_help(self.gladefile,self.global_vars["help_path"],"index.html")
+	
+	
 	# help methods
 
 	def callback2(self):
@@ -809,7 +852,7 @@ class main_window:
 			del_title.set_sensitive(False)
 		
 		add_title=self.tree.get_widget("add_title")
-		if (len(self.structure)<12):
+		if (len(self.structure)<90):
 			add_title.set_sensitive(True)
 		else:
 			add_title.set_sensitive(False)
@@ -866,7 +909,8 @@ class main_window:
 			w.set_text(str(found["arate"]))
 			
 			w=self.tree.get_widget("eleng")
-			length=devede_other.calcula_tamano_parcial(found["vrate"],found["arate"],found["filesize"],found["olength"],len(found["sub_list"]),found["ismpeg"],found["cutting"])
+			speed1,speed2=devede_other.get_speedup(found)
+			length=devede_other.calcula_tamano_parcial(found["vrate"],found["arate"],found["filesize"],found["olength"],len(found["sub_list"]),found["ismpeg"],found["cutting"],speed1,speed2)
 			#length=int(((found["vrate"]+found["arate"])*found["olength"])/8000)
 			w.set_text(str(int(length/1000)))
 			
@@ -911,7 +955,7 @@ class main_window:
 			w=self.tree.get_widget("fsizem")
 			w.set_text("")
 			
-		total=devede_other.calcula_tamano_total(self.structure)
+		total=devede_other.calcula_tamano_total(self.structure,self.global_vars["menu_sound_duration"],self.disctocreate)
 		total/=1000
 		
 		tamano,minvrate,maxvrate = devede_other.get_dvd_size(self.tree,self.disctocreate)
