@@ -29,13 +29,79 @@ import subprocess
 import stat
 import sys
 import shutil
+import cairo
+
 if sys.platform == 'win32':
 	import devede_executor
 
 
-def calcula_tamano_parcial(vrate,arate,filesize,length,subs,ismpeg,cutting):
+def get_speedup(videofile):
+	
+	""" configure speedup values when the original file
+		is 23.976 or 24 fps and final file is 25 fps (PAL)
+		this allows to avoid jerky jumps during reproduction """
+		
+	# First, check if the original is XX.9XX or XX.000 fps
+	
+	print "OFPS2: "+str(videofile["ofps2"])
+	rational_fps=False
+	pos=videofile["ofps2"].find(".")
+	if (pos!=-1) and (len(videofile["ofps2"])>(pos+1)):
+		if (videofile["ofps2"][pos+1]=="9"):
+			rational_fps=True
+			
+	print "Rational_fps: "+str(rational_fps)
+	
+	# if it's rational, we have to use a different pair of values to achieve good precission
+	
+	if (videofile["ofps"]==24) and (videofile["fps"]==25) and (videofile["copy_audio"]==False) and (videofile["ismpeg"]==False):
+		if rational_fps:
+			return 25025,24000
+		else:
+			return 25,24
+	else:
+		return 1,1
 
-	""" Calculates the stimated final size.
+
+def get_font_params(font_name):
+	
+	font_elements=[]
+	font_temp=font_name
+
+	font_elements=font_name.split(" ")
+	
+	if (len(font_elements))<2:
+		fontname="Sans"
+		fontstyle=cairo.FONT_WEIGHT_NORMAL
+		fontslant=cairo.FONT_SLANT_NORMAL
+		fontsize=12
+	else:
+		fontname=""
+		fontstyle=cairo.FONT_WEIGHT_NORMAL
+		fontslant=cairo.FONT_SLANT_NORMAL
+		for counter2 in range(len(font_elements)-1):
+			if font_elements[counter2]=="Bold":
+				fontstyle=cairo.FONT_WEIGHT_BOLD
+			elif font_elements[counter2]=="Italic":
+				fontslant=cairo.FONT_SLANT_ITALIC
+			else:
+				fontname+=" "+font_elements[counter2]
+		if fontname!="":
+			fontname=fontname[1:]
+		else:
+			fontname="Sans"
+
+	try:
+		fontsize=float(font_elements[-1])
+	except:
+		fontsize=12
+		
+	return fontname,fontstyle,fontslant,fontsize
+
+
+def calcula_tamano_parcial(vrate,arate,filesize,length,subs,ismpeg,cutting,speed1,speed2):
+
+	""" Calculates the estimated final size.
 	
 	VRATE and ARATE is the bit rate for video and audio.
 	FILESIZE is the size of the original file.
@@ -46,6 +112,9 @@ def calcula_tamano_parcial(vrate,arate,filesize,length,subs,ismpeg,cutting):
 	
 	"""
 
+	if (speed1!=speed2): # we are speeding up the film, so we must take it into account
+		length=int((float(length))*((float(speed2))/(float(speed1))))
+
 	if ismpeg:
 		l=filesize/1000
 	else:
@@ -56,15 +125,25 @@ def calcula_tamano_parcial(vrate,arate,filesize,length,subs,ismpeg,cutting):
 	return l
 
 
-def calcula_tamano_total(structure):
+def calcule_menu_size(structure,sound_duration):
+
+	# each menu needs 1128 kbits/sec * sound_duration / 8
+	return (141*sound_duration)*((len(structure)+9)/10)
+
+
+def calcula_tamano_total(structure,sound_duration,disktype):
 
 	""" Calculates the total size of the DVD """
 
+	print "Calculating size for disk :"+str(disktype)
 	total=0.0
 	for element in structure:
 		if len(element)>1:
 			for film in element[1:]:
-				total+=calcula_tamano_parcial(film["vrate"],film["arate"],film["filesize"],film["olength"],len(film["sub_list"]),film["ismpeg"],film["cutting"])
+				speed1,speed2=get_speedup(film)
+				total+=calcula_tamano_parcial(film["vrate"],film["arate"],film["filesize"],film["olength"],len(film["sub_list"]),film["ismpeg"],film["cutting"],speed1,speed2)
+	if disktype=="dvd":
+		total+=calcule_menu_size(structure,sound_duration)
 	return total
 
 
@@ -88,7 +167,7 @@ def load_config(global_vars):
 	""" Load the configuration """
 	home=get_home_directory()
 	global_vars["PAL"]=True
-	global_vars["multicore"]=1
+	global_vars["multicore"]=1 # it shouldn't use multicore by default
 
 	# TODO change to allow a windows temp directory
 
@@ -127,22 +206,12 @@ def load_config(global_vars):
 					global_vars["PAL"]=False
 			if linea[:12]=="temp_folder:":
 				global_vars["temp_folder"]=linea[12:]
-			if linea[:12]=="menu_format:":
-				if linea[12:]=="pal":
-					menuformat_found=True
-					global_vars["menu_PAL"]=True
-				if linea[12:]=="ntsc":
-					menuformat_found=True
-					global_vars["menu_PAL"]=False
 			if linea[:10]=="multicore:":
-				global_vars["multicore"]=int(linea[10:])
+				global_vars["multicore"]=int(linea[10:]) # don't remember multicore
 		archivo.close()
 	except IOError:
 		pass
 
-	if menuformat_found==False:
-		global_vars["menu_PAL"]=global_vars["PAL"] # if it's still not defined, we use the same format than the others
-
 
 def save_config(global_vars):
 
@@ -167,10 +236,6 @@ def save_config(global_vars):
 		else:
 			archivo.write("video_format:ntsc\n")
 		archivo.write("temp_folder:"+global_vars["temp_folder"]+"\n")
-		if global_vars["menu_PAL"]:
-			archivo.write("menu_format:pal\n")
-		else:
-			archivo.write("menu_format:ntsc\n")
 		archivo.write("multicore:"+str(global_vars["multicore"])+"\n")
 		archivo.close()
 	except IOError:
@@ -302,7 +367,7 @@ def get_dvd_size(tree,disctocreate):
 		maxvrate=2300
 	elif (disctocreate=="dvd"):
 		minvrate=400
-		maxvrate=8000
+		maxvrate=8500
 	elif (disctocreate=="divx"):
 		minvrate=300
 		maxvrate=6000
@@ -313,3 +378,25 @@ def get_dvd_size(tree,disctocreate):
 	
 	return tamano,minvrate,maxvrate
 
+
+def get_picture_type(filename):
+	
+	try:
+		f=open(filename,"r")
+	except:
+		return ""
+	
+	ftype=""
+	line=f.read(4)
+
+	if (line[0]=="\211") and (line[1:]=="PNG"):
+		ftype="png"
+	
+	line2=f.read(7)
+	if (line[0]=="\377") and (line[1]=="\330") and (line[2]=="\377") and (line[3]=="\340") and (line2[2:6]=="JFIF") and (line2[6]=="\000"):
+		ftype="jpeg"
+		
+	f.close()
+	print "tipo: "+str(ftype)
+	return ftype
+	
